@@ -52,16 +52,17 @@ namespace massXpert
 				      Polymer *polymer,
 				      const PolChemDef *polChemDef,
 				      const CalcOptions &calcOptions,
-				      const IonizeRule &ionizeRule)
+				      const IonizeRule *ionizeRule)
     : QDialog(parent),
       mp_polymer(polymer), 
       mp_polChemDef(polChemDef), 
       m_calcOptions(calcOptions),
-      m_ionizeRule(ionizeRule)
+      mp_ionizeRule(ionizeRule)
   {
     Q_ASSERT(parent);
     Q_ASSERT(!mp_polymer.isNull() && mp_polChemDef);
-  
+    Q_ASSERT(mp_ionizeRule);
+    
     m_ui.setupUi(this);
   
     mp_editorWnd = static_cast<SequenceEditorWnd *>(parent);
@@ -184,9 +185,8 @@ namespace massXpert
   {
     delete mpa_oligomerTreeViewModel;
     delete mpa_proxyModel;
-
-    if (mpa_fragmenter)
-      delete mpa_fragmenter;
+    delete mpa_fragmenter;
+    delete mpa_resultsString;
   }
 
 
@@ -385,32 +385,36 @@ namespace massXpert
     // called many time, which means that we first have to free the
     // mpa_fragmenter allocated member if non-0.
 
-    if (mpa_fragmenter)
-      delete mpa_fragmenter;
+    delete mpa_fragmenter;
+    mpa_fragmenter = 0;
     
     mpa_fragmenter = new Fragmenter(mp_polymer, mp_polChemDef,
 				     fragOptionList, 
-				     m_calcOptions, m_ionizeRule);
+				     m_calcOptions, *mp_ionizeRule);
   
     if (!mpa_fragmenter->fragment())
       {
 	delete mpa_fragmenter;
       
-	qDebug() << __FILE__ << __LINE__
-		  << "Failed to perform fragmentation";
+	QMessageBox msgBox;
+
+	msgBox.setText("Failed to perform the fragmentation.");
+
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
       
 	return;
       }
   
     QList<OligomerList *> &dataList = mpa_fragmenter->oligomerLists();
   
-
-    if (mpa_oligomerTreeViewModel)
-      delete mpa_oligomerTreeViewModel;
-
-    if (mpa_proxyModel)
-      delete mpa_proxyModel;
-  
+    delete mpa_oligomerTreeViewModel;
+    mpa_oligomerTreeViewModel = 0;
+    
+    delete mpa_proxyModel;
+    mpa_proxyModel = 0;
+    
     // Model stuff all thought for sorting.
     mpa_oligomerTreeViewModel = 
       new FragmentOligomerTreeViewModel(&dataList, this);
