@@ -225,10 +225,10 @@ namespace massXpert
 	     this,
 	     SLOT(incrementChargePushButton()));
   
-    connect(m_ui.applyIonizeRulePushButton,
+    connect(m_ui.reionizePushButton,
 	     SIGNAL(clicked()),
 	     this,
-	     SLOT(applyIonizeRulePushButton()));
+	     SLOT(reionizePushButton()));
   
     connect(m_ui.performMatchesPushButton,
 	     SIGNAL(clicked()),
@@ -240,12 +240,12 @@ namespace massXpert
 	     this,
 	     SLOT(newInputList()));
 
-    connect(m_ui.input1ListWidget,
+    connect(m_ui.catalogue1ListWidget,
 	     SIGNAL(itemClicked(QListWidgetItem *)),
 	     this,
 	     SLOT(inputListWidgetItemClicked(QListWidgetItem *)));
     
-    connect(m_ui.input2ListWidget,
+    connect(m_ui.catalogue2ListWidget,
 	     SIGNAL(itemClicked(QListWidgetItem *)),
 	     this,
 	     SLOT(inputListWidgetItemClicked(QListWidgetItem *)));
@@ -592,7 +592,7 @@ namespace massXpert
 
 
   void
-  MzLabWnd::applyIonizeRulePushButton()
+  MzLabWnd::reionizePushButton()
   {
     MzLabInputOligomerTreeViewDlg *dlg = 0;
     
@@ -778,12 +778,14 @@ namespace massXpert
       .arg(dlg1->name())
       .arg(dlg2->name());
    
+    // Ownership of oligomerPairList is going to be transferred to the
+    // dialog being created (note that to the dialog and not the tree
+    // view model in the dialog's tree view).
 
     MzLabOutputOligomerTreeViewDlg *dlg =
       new MzLabOutputOligomerTreeViewDlg(this, oligomerPairList, 
 					 massType1,
 					 dlg1, dlg2, dialogName);
-   
     dlg->show();
   }
    
@@ -795,10 +797,10 @@ namespace massXpert
     
     // Which list of lists is selected ?
     
-    if (m_ui.input1ListRadioButton->isChecked())
-      item = m_ui.input1ListWidget->currentItem();
+    if (m_ui.catalogue1RadioButton->isChecked())
+      item = m_ui.catalogue1ListWidget->currentItem();
     else
-      item = m_ui.input2ListWidget->currentItem();
+      item = m_ui.catalogue2ListWidget->currentItem();
     
     if (!item)
       return false;
@@ -826,8 +828,8 @@ namespace massXpert
 
     // Which lists of lists is selected ?
     
-    item1 = m_ui.input1ListWidget->currentItem();
-    item2 = m_ui.input2ListWidget->currentItem();
+    item1 = m_ui.catalogue1ListWidget->currentItem();
+    item2 = m_ui.catalogue2ListWidget->currentItem();
     
     if (!item1 || !item2)
       return false;
@@ -891,8 +893,8 @@ namespace massXpert
     
     // Now we can add the item to the lists of input...
 
-    m_ui.input1ListWidget->addItem(name);
-    m_ui.input2ListWidget->addItem(name);
+    m_ui.catalogue1ListWidget->addItem(name);
+    m_ui.catalogue2ListWidget->addItem(name);
 
     // Finally we can add the list to the list of dialog windows.
     
@@ -936,7 +938,7 @@ namespace massXpert
   {
     // Do this for input 1 list only.
 
-    QListWidgetItem *item = m_ui.input1ListWidget->currentItem();
+    QListWidgetItem *item = m_ui.catalogue1ListWidget->currentItem();
     if (!item)
       return ;
 
@@ -975,24 +977,24 @@ namespace massXpert
     // Update the listWidgets(1 and 2) corresponding items.
     
     QList<QListWidgetItem *> list = 
-      m_ui.input1ListWidget->findItems(name,
+      m_ui.catalogue1ListWidget->findItems(name,
 					Qt::MatchExactly);
     Q_ASSERT(list.size() == 1);
     
     QListWidgetItem *item = list.first();
     
-    m_ui.input1ListWidget->takeItem(m_ui.input1ListWidget->row(item));
+    m_ui.catalogue1ListWidget->takeItem(m_ui.catalogue1ListWidget->row(item));
     
     if (item)
       delete(item);
 
-    list = m_ui.input2ListWidget->findItems(name,
+    list = m_ui.catalogue2ListWidget->findItems(name,
 					     Qt::MatchExactly);
     Q_ASSERT(list.size() == 1);
     
     item = list.first();
     
-    m_ui.input2ListWidget->takeItem(m_ui.input2ListWidget->row(item));
+    m_ui.catalogue2ListWidget->takeItem(m_ui.catalogue2ListWidget->row(item));
     
     if (item)
       delete(item);
