@@ -90,19 +90,12 @@ namespace massXpert
   PolChemDefWnd::~PolChemDefWnd()
   {
     // These values must have been set to 0 in the constructor !!!
-    // These values must have been set to 0 in the constructor !!!
-    if (mpa_atomDefDlg)
-      delete mpa_atomDefDlg;
-    if (mpa_monomerDefDlg)
-      delete mpa_monomerDefDlg;
-    if (mpa_modifDefDlg)
-      delete mpa_modifDefDlg;
-    if (mpa_cleaveSpecDefDlg)
-      delete mpa_cleaveSpecDefDlg;
-    if (mpa_fragSpecDefDlg)
-      delete mpa_fragSpecDefDlg;
-    if (mpa_crossLinkerDefDlg)
-      delete mpa_crossLinkerDefDlg;
+    delete mpa_atomDefDlg;
+    delete mpa_monomerDefDlg;
+    delete mpa_modifDefDlg;
+    delete mpa_cleaveSpecDefDlg;
+    delete mpa_fragSpecDefDlg;
+    delete mpa_crossLinkerDefDlg;
   }
 
 
@@ -815,7 +808,7 @@ namespace massXpert
       }
     else
       statusBar()->showMessage(tr("Polymer chemistry definition "
-				     "data validation succeeded."));
+				  "data validation succeeded."));
   
     return errorCount;
   }
@@ -871,10 +864,15 @@ namespace massXpert
     if (ret)
       {
 	// Errors encountered.
-	QMessageBox::warning 
-	 (this, tr("massXpert - Polymer Chemistry Definition"),
-	   tr("Errors were encountered. Cannot save"),
-	   QMessageBox::Ok);
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, validate the definition "
+				  "prior to saving to file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
 
 	return false;
       }
@@ -885,6 +883,16 @@ namespace massXpert
     if (!m_polChemDef.writeXmlFile())
       {
 	statusBar()->showMessage(tr("File save failed."), 3000);
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, check that you have "
+				  "write permissions on the file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
+
 	return false;
       }
 
@@ -913,11 +921,16 @@ namespace massXpert
     if (ret != 0)
       {
 	// Errors encountered.
-	QMessageBox::warning 
-	 (this, tr("massXpert - Polymer Chemistry Definition"),
-	   tr("Errors were encountered. Cannot save."),
-	   QMessageBox::Ok);
-      
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, validate the definition "
+				  "prior to saving to file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
+
 	return false;
       }
   
@@ -939,6 +952,16 @@ namespace massXpert
     if (!m_polChemDef.writeXmlFile())
       {
 	statusBar()->showMessage(tr("File save failed."), 3000);
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, check that you have "
+				  "write permissions on the file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
+
 	return false;
       }
   
