@@ -76,7 +76,7 @@ namespace massXpert
   
     if (!preInitialize())
       {
-	QMessageBox::warning(0, 
+	QMessageBox::warning(this, 
 			      tr("massXpert - Polymer Sequence Editor"),
 			      tr("Failed to pre-initialize the polymer "
 				  "sequence editor window."),
@@ -121,6 +121,9 @@ namespace massXpert
     settings.setValue("hSplitterSize", m_ui.hSplitter->saveState());
     settings.setValue("vSplitterSize", m_ui.vSplitter->saveState());
 
+    settings.setValue("calcEngineMonomersToolBox",
+		      m_ui.calcEngineMonomersToolBox->currentIndex());
+
     settings.endGroup();
   }
 
@@ -144,6 +147,9 @@ namespace massXpert
     m_ui.hSplitter->
       restoreState(settings.value("hSplitterSize").toByteArray());
 
+    m_ui.calcEngineMonomersToolBox->
+      setCurrentIndex(settings.value("calcEngineMonomersToolBox").toInt());
+    
     settings.endGroup();
   }
 
@@ -446,7 +452,7 @@ namespace massXpert
   
     if (!file.open(QIODevice::WriteOnly | QIODevice::Append))
       {
-	QMessageBox::information(0, 
+	QMessageBox::information(this, 
 				  tr("massXpert - Export Data"),
 				  tr("Failed to open file in append mode."),
 				  QMessageBox::Ok);
@@ -501,19 +507,19 @@ namespace massXpert
     connect(saveAct, SIGNAL(triggered()), this, SLOT(save()));
   
     // File/SaveAs
-    saveAsAct = new QAction(tr("Save&As"), this);
+    saveAsAct = new QAction(tr("Save&as"), this);
     saveAsAct->setShortcut(tr("Ctrl+Alt+S"));
     saveAsAct->setStatusTip(tr("Saves the sequence in another file"));
     connect(saveAsAct, SIGNAL(triggered()), this, SLOT(saveAs()));
   
     // File/ImportRaw
-    importRawAct = new QAction(tr("&Import Raw"), this);
+    importRawAct = new QAction(tr("&Import raw"), this);
     importRawAct->setShortcut(tr("Ctrl+I"));
     importRawAct->setStatusTip(tr("Imports a raw text file"));
     connect(importRawAct, SIGNAL(triggered()), this, SLOT(importRaw()));
   
     // File/ExportClipboard
-    exportClipboardAct = new QAction(tr("Export to &Clipboard"), this);
+    exportClipboardAct = new QAction(tr("Export to &clipboard"), this);
     exportClipboardAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_E,Qt::Key_C));
     exportClipboardAct->setStatusTip(tr("Export as text to the clipboard"));
@@ -521,7 +527,7 @@ namespace massXpert
 	     this, SLOT(exportClipboard()));
   
     // File/ExportFile
-    exportFileAct = new QAction(tr("Export to &File"), this);
+    exportFileAct = new QAction(tr("Export to &file"), this);
     exportFileAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_E,Qt::Key_F));
     exportFileAct->setStatusTip(tr("Export as text to file"));
@@ -529,7 +535,7 @@ namespace massXpert
 	     this, SLOT(exportFile()));
   
     // File/ExportSelectFile
-    exportSelectFileAct = new QAction(tr("&Select Export File"), this);
+    exportSelectFileAct = new QAction(tr("&Select export file"), this);
     exportSelectFileAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_E,Qt::Key_S));
     exportSelectFileAct->setStatusTip(tr("Select file to export as text to"));
@@ -562,7 +568,7 @@ namespace massXpert
 	     this, SLOT(clipboardPaste()));
 
     // Edit/Find Sequence
-    findSequenceAct = new QAction(tr("&Find Sequence"), this);
+    findSequenceAct = new QAction(tr("&Find sequence"), this);
     findSequenceAct->setShortcut(tr("Ctrl+F"));
     findSequenceAct->setStatusTip(tr("Find a sequence "
 				       "in the polymer sequence"));
@@ -571,7 +577,7 @@ namespace massXpert
   
 
     // Chemistry/ModifyMonomer
-    modifMonomerAct = new QAction(tr("Modify &Monomer(s)"), this);
+    modifMonomerAct = new QAction(tr("Modify &monomer(s)"), this);
     modifMonomerAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_M,Qt::Key_M));
     modifMonomerAct->setStatusTip(tr("Modifies monomer(s)"));
@@ -579,7 +585,7 @@ namespace massXpert
 	     SLOT(modifMonomer()));
   
     // Chemistry/ModifyPolymer
-    modifPolymerAct = new QAction(tr("Modify &Polymer"), this);
+    modifPolymerAct = new QAction(tr("Modify &polymer"), this);
     modifPolymerAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_M,Qt::Key_P));
     modifPolymerAct->setStatusTip(tr("Modifies the polymer"));
@@ -600,7 +606,7 @@ namespace massXpert
 	     SLOT(modifRightEnd()));
 
     // Chemistry/CrossLinkMonomer
-    crossLinkMonomersAct = new QAction(tr("Cross-&link Monomers"), this);
+    crossLinkMonomersAct = new QAction(tr("Cross-&link monomers"), this);
     crossLinkMonomersAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_L,Qt::Key_M));
     crossLinkMonomersAct->setStatusTip(tr("Cross-link monomers"));
@@ -624,7 +630,7 @@ namespace massXpert
 	     SLOT(fragment()));
   
     // Chemistry/MassSearch
-    massSearchAct = new QAction(tr("&Mass Search"), this);
+    massSearchAct = new QAction(tr("Search &masses"), this);
     massSearchAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_M,Qt::Key_S));
     massSearchAct->setStatusTip(tr("Search oligomers based on mass"));
@@ -632,7 +638,7 @@ namespace massXpert
 	     SLOT(massSearch()));
   
     // Chemistry/mzCalculation
-    mzCalculationAct = new QAction(tr("Compute m/z &Ratios"), this);
+    mzCalculationAct = new QAction(tr("Compute m/z &ratios"), this);
     mzCalculationAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_M,Qt::Key_Z));
     mzCalculationAct->setStatusTip(tr("Compute ion charge families"));
@@ -640,10 +646,10 @@ namespace massXpert
 	     SLOT(mzCalculation()));
   
     // Chemistry/compositions
-    compositionsAct = new QAction(tr("Determine Compositions"), this);
+    compositionsAct = new QAction(tr("Determine compositions"), this);
     compositionsAct->setShortcut 
      (QKeySequence(Qt::CTRL+Qt::Key_D,Qt::Key_C));
-    compositionsAct->setStatusTip(tr("Determine Compositions"));
+    compositionsAct->setStatusTip(tr("Determine compositions"));
     connect(compositionsAct, SIGNAL(triggered()), this, 
 	     SLOT(compositions()));
   
@@ -793,7 +799,7 @@ namespace massXpert
 
     if (!populateMonomerCodeList())
       {
-	QMessageBox::warning(0, 
+	QMessageBox::warning(this, 
 			      tr("massXpert - Polymer Sequence Editor"),
 			      tr("%1@%2\n"
 				  "Failed to populate the monomer code list.")
@@ -807,7 +813,7 @@ namespace massXpert
     populateCalculationOptions();
   
     m_ui.vignetteListWidget->setSelectionMode 
-     (QAbstractItemView::SingleSelection);
+     (QAbstractItemView::MultiSelection);
 
 
     ////// Connection of the SIGNALS and SLOTS //////
@@ -917,7 +923,7 @@ namespace massXpert
 
     if (filePath.isEmpty() || !QFile::exists(filePath))
       {
-	QMessageBox::warning(0, 
+	QMessageBox::warning(this, 
 			      tr("massXpert - Polymer Sequence Editor"),
 			      tr("%1@%2\n"
 				  "Filepath is empty, or file does not exist.")
@@ -934,7 +940,7 @@ namespace massXpert
     if (name.isEmpty())
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to get the polymer chemistry definition name.")
@@ -950,7 +956,7 @@ namespace massXpert
     if (!mp_polChemDef)
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to prepare the polymer chemistry definition.")
@@ -969,7 +975,7 @@ namespace massXpert
     if (!readFile(filePath))
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to load the polymer file.")
@@ -986,7 +992,7 @@ namespace massXpert
     if (mpa_editorGraphicsView->drawSequence() == -1)
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to draw the polymer sequence.")
@@ -1020,7 +1026,7 @@ namespace massXpert
     if (!polChemDefSpec)
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to find the corresponding polymer chemistry "
@@ -1037,7 +1043,7 @@ namespace massXpert
     if (!mp_polChemDef)
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to prepare the polymer chemistry definition.")
@@ -1057,7 +1063,7 @@ namespace massXpert
     if (mpa_editorGraphicsView->drawSequence() == -1)
       {
 	QMessageBox::warning 
-	 (0, 
+	 (this, 
 	   tr("massXpert - Polymer Sequence Editor"),
 	   tr("%1@%2\n"
 	       "Failed to draw the polymer sequence.")
@@ -1105,7 +1111,7 @@ namespace massXpert
 	    // registered to the system. We cannot go further.
 
 	    QMessageBox::warning 
-	     (0, 
+	     (this, 
 	       tr("massXpert - Polymer Sequence Editor"),
 	       tr("%1@%2\n"
 		   "Failed to get the polymer chemistry "
@@ -1128,7 +1134,7 @@ namespace massXpert
 	    delete polChemDef;
 
 	    QMessageBox::warning 
-	     (0, 
+	     (this, 
 	       tr("massXpert - Polymer Sequence Editor"),
 	       tr("%1@%2\n"
 		   "Failed to render the polymer chemistry"
@@ -1151,7 +1157,7 @@ namespace massXpert
 	    delete polChemDef;
 	  
 	    QMessageBox::warning 
-	     (0, 
+	     (this, 
 	       tr("massXpert - Polymer Sequence Editor"),
 	       tr("%1@%2\n"
 		   "Failed to parse the monomer dictionary file.")
@@ -1171,7 +1177,7 @@ namespace massXpert
 	    delete polChemDef;
 	  
 	    QMessageBox::warning 
-	     (0, 
+	     (this, 
 	       tr("massXpert - Polymer Sequence Editor"),
 	       tr("%1@%2\n"
 		   "Failed to parse the modification dictionary file.")
@@ -1191,7 +1197,7 @@ namespace massXpert
 	    delete polChemDef;
 	  
 	    QMessageBox::warning 
-	     (0, 
+	     (this, 
 	       tr("massXpert - Polymer Sequence Editor"),
 	       tr("%1@%2\n"
 		   "Failed to parse the cross-linker dictionary file.")
@@ -1288,25 +1294,24 @@ namespace massXpert
   
     // IONIZATION RULE
 
-    const PolChemDef *polChemDef = mpa_polymer->polChemDef();
-
     QString text = m_ui.ionizationFormulaLineEdit->text();
   
     if (!text.isEmpty())
       {
-	Formula formula(text);
-      
+	const PolChemDef *polChemDef = mpa_polymer->polChemDef();
 	const QList<Atom *> &refList = polChemDef->atomList();
       
+	Formula formula(text);
+      
 	if(!formula.validate(refList))
 	  {
-	    QMessageBox::warning(0,
-				  tr("massXpert - Polymer Sequence Editor"),
-				  tr("Ionization rule formula is not valid."),
-				  QMessageBox::Ok);
-	  
+	    QMessageBox::warning(this,
+				 tr("massXpert - Polymer Sequence Editor"),
+				 tr("Ionization rule formula is not valid."),
+				 QMessageBox::Ok);
+	    
 	    m_ui.ionizationFormulaLineEdit->setFocus();
-	  
+	    
 	    return;
 	  }
       
@@ -1815,11 +1820,11 @@ namespace massXpert
       {
 	// We have increment all end indices for the items in the
 	// coordinateList by one unit. See above for the explanation.
-	for(int iter = 0; iter < coordinateList.size(); ++iter)
-	  {
+	// for(int iter = 0; iter < coordinateList.size(); ++iter)
+	//  {
 	    // No, we do not need to do this anymore.
 	    // coordinateList.at(iter)->incrementEnd();
-	  }
+	//  }
       }
     
     m_calcOptions.setCoordinateList(coordinateList);
@@ -1838,6 +1843,14 @@ namespace massXpert
     m_ui.avgSelectionMassLineEdit->
       setText(mpa_polymer->avg(application->locale(),
 				 MXP_OLIGOMER_DEC_PLACES));  
+
+    // At this point, we can display the selection coordinates:
+    QString selectionPositions = coordinateList.positionsAsText();
+
+//     qDebug() << __FILE__ << __LINE__
+// 	     << "positions:" << selectionPositions;
+
+    m_ui.selectionLineEdit->setText(selectionPositions);
   }
 
 
@@ -1892,6 +1905,16 @@ namespace massXpert
     if (!mpa_polymer->writeXmlFile())
       {
 	statusBar()->showMessage(tr("File save failed."));
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, check that you have "
+				  "write permissions on the file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
+
 	return false;
       }
   
@@ -1914,7 +1937,7 @@ namespace massXpert
     QString filePath = 
       QFileDialog::getSaveFileName(this, tr("Save Polymer Sequence File"),
 				    QDir::homePath(),
-				    tr("XML files(*.mxp *.mXp *.MXP)"));
+				    tr("mXp files(*.mxp *.mXp *.MXP)"));
   
     if (filePath.isEmpty())
       {
@@ -1927,6 +1950,16 @@ namespace massXpert
     if (!mpa_polymer->writeXmlFile())
       {
 	statusBar()->showMessage(tr("File save failed."));
+
+	QMessageBox msgBox;
+	
+	msgBox.setText("Failed to save the document.");
+	msgBox.setInformativeText("Please, check that you have "
+				  "write permissions on the file.");
+	msgBox.setStandardButtons(QMessageBox::Ok);
+	
+	msgBox.exec();
+
 	return false;
       }
   
@@ -1994,7 +2027,7 @@ namespace massXpert
   
     if ( ret != size)
       {
-	QMessageBox::critical(0, 
+	QMessageBox::critical(this, 
 			       tr("massXpert - Polymer Sequence Editor"),
 			       tr("Failed to import the sequence."),
 			       QMessageBox::Ok);
@@ -2150,7 +2183,7 @@ namespace massXpert
   
     if (ret != size)
       {
-	QMessageBox::critical(0, 
+	QMessageBox::critical(this, 
 			       tr("massXpert - Polymer Sequence Editor"),
 			       tr("Failed to paste the sequence."),
 			       QMessageBox::Ok);
@@ -2317,7 +2350,7 @@ namespace massXpert
 			    mpa_polymer,
 			    mpa_polymer->polChemDef(),
 			    m_calcOptions,
-			    m_ionizeRule);
+			    &m_ionizeRule);
   
     dlg->show();
   }
