@@ -364,6 +364,43 @@ namespace massXpert
     return actions(m_formula);
   }
 
+  // Returns the number of removed characters.
+  int
+  Formula::removeTitle()
+  {
+    int length = m_formula.length();
+    
+    // We want to remove the possibly-existing title for the formula,
+    // which is enclosed between `"' at the beginning of the line.
+
+    // One formula can be like this:
+
+    // "Decomposed adenine" C5H4N5 +H 
+
+    // The "Decomposed adenine" is the title
+    // The C5H4N5 +H is the formula.
+    
+    m_formula.remove(QRegExp("\".*\""));
+
+    // Return the number of removed characters.
+    return (length - m_formula.length());
+  }
+  
+
+  // Returns the number of removed characters.
+  int
+  Formula::removeSpaces()
+  {
+    int length = m_formula.length();
+    
+    // We want to remove all the possibly-existing spaces.
+    
+    m_formula.remove(QRegExp("\\s+"));
+
+    // Return the number of removed characters.
+    return (length - m_formula.length());
+  }
+  
 
   //! Splits the formula according to its plus-/minus- actions.
   /*! Analyzes the formula and separates all the minus components of
@@ -417,13 +454,32 @@ namespace massXpert
     m_plusFormula.clear();
     m_minusFormula.clear();
 
+    // Because the formula that we are analyzing might contain a title
+    // and spaces , we first remove these. But make a local copy of
+    // the member datum.
+
+    QString formula = m_formula;
+    
+    // One formula can be like this:
+
+    // "Decomposed adenine" C5H4N5 +H 
+
+    // The "Decomposed adenine" is the title
+    // The C5H4N5 +H is the formula.
+    
+    formula.remove(QRegExp("\".*\""));
+
+    // We want to remove all the possibly-existing spaces.
+    
+    formula.remove(QRegExp("\\s+"));
+    
     // If the formula does not contain any '-' character, then we
     // can approximate that all the formula is a '+' formula, that is a
     // plusFormula:
 	
     if (actions() == '+')
       {
-	m_plusFormula.append(m_formula);
+	m_plusFormula.append(formula);
 		
 	// At this point we want to make sure that we have a correct
 	// formula. Remove all the occurrences of the '+' sign.
@@ -440,9 +496,9 @@ namespace massXpert
   
     // At this point, we truly have to iterate in the formula...
   
-    for (int iter = 0 ; iter < m_formula.length() ; ++iter)
+    for (int iter = 0 ; iter < formula.length() ; ++iter)
       {
-	curChar = m_formula.at(iter);
+	curChar = formula.at(iter);
 	//       qDebug() << "curChar:" << curChar;
       
 	if(curChar == '+' || curChar == '-')
@@ -495,7 +551,7 @@ namespace massXpert
 
 	    continue;
 	  }
-      } // End for (int iter = 0 ; iter < m_formula.length() ; ++iter)
+      } // End for (int iter = 0 ; iter < formula.length() ; ++iter)
 
     // At this point the loop was finished so we might have something
     // interesting cooking:
@@ -539,7 +595,7 @@ namespace massXpert
       }
   
     //   qDebug() << __FILE__ << __LINE__
-    // 	    << m_formula.toAscii() << "-->" 
+    // 	    << formula.toAscii() << "-->" 
     // 	    << "(+)" << m_plusFormula.toAscii() 
     // 	    << "(-)" << m_minusFormula.toAscii();
   
@@ -600,7 +656,7 @@ namespace massXpert
     if (formula.length() == 0)
       return true;
 
-    if (!checkSyntax())
+    if (!checkSyntax(formula))
       return false;
 
     // Also, the first character of the formula should be an Uppercase
@@ -847,9 +903,19 @@ namespace massXpert
 	  
 	    // If the caller wants to get a numerical feedback on the
 	    // new count for current atomCount, then update newcount.
-	    if (newcount != 0)
+	    if (newcount)
 	      *newcount = iter_atomCount->count();
 	  
+	    // Note that is the result of the operation above is to
+	    // have a 0-count item, we can remove it.
+
+	    if (!iter_atomCount->count())
+	      {
+		m_atomCountList.removeAt(iter);
+		
+		delete iter_atomCount;
+	      }
+	    
 	    // Because we update a pre-existing atomcount object, we do
 	    // not need to put the atomcount in the list. Return false,
 	    // so that the caller knows that it can delete that object.
@@ -887,7 +953,7 @@ namespace massXpert
     \sa validate().
   */
   bool
-  Formula::checkSyntax(QString &formula)
+  Formula::checkSyntax(const QString &formula)
   {
     QChar curChar;
 
@@ -895,10 +961,30 @@ namespace massXpert
     bool gotUpper = false;
     bool wasUpper = false;
     bool wasSign = false;
+
+    // Because the formula that we are analyzing might contain a title
+    // and spaces , we first remove these. But make a local copy of
+    // the member datum.
+
+    QString localFormula = formula;
+    
+    // One formula can be like this:
+
+    // "Decomposed adenine" C5H4N5 +H 
+
+    // The "Decomposed adenine" is the title
+    // The C5H4N5 +H is the formula.
+    
+    localFormula.remove(QRegExp("\".*\""));
+
+    // We want to remove all the possibly-existing spaces.
+    
+    localFormula.remove(QRegExp("\\s+"));
+    
   
-    for (int iter = 0 ; iter < formula.length() ; ++iter)
+    for (int iter = 0 ; iter < localFormula.length() ; ++iter)
       {
-	curChar = formula.at(iter);
+	curChar = localFormula.at(iter);
 
 	if(curChar.category() == QChar::Number_DecimalDigit)
 	  {
@@ -923,6 +1009,7 @@ namespace massXpert
 	    if (!gotUpper)
 	      return false;
 
+
 	    // We may not have a lowercase character after a +/- sign.
 	    if (wasSign)
 	      return false;
@@ -962,7 +1049,7 @@ namespace massXpert
 	    wasUpper = false;
 	  }
       }
-    // end for (int iter = 0 ; iter < formula.length() ; ++iter)
+    // end for (int iter = 0 ; iter < localFormula.length() ; ++iter)
 
     // At this point we found no error condition.
     return true;
@@ -996,6 +1083,17 @@ namespace massXpert
   }
 
 
+  QString 
+  Formula::simplify()
+  {
+    // We have +CH3 -C +C2H6O4N5P
+    // We want to have the result of this: that is C2H8O4N5P
+    
+    return elementalComposition();
+  }
+  
+
+
   //! Validates the formula.
   /*! The validation of the formula involves:
 
@@ -1159,18 +1257,71 @@ namespace massXpert
   Formula::elementalComposition() const
   {
     QString composition;
-  
+    bool nextNegative = false;
+    
     for (int iter = 0; iter < m_atomCountList.size(); ++iter)
       {
 	AtomCount *atomCount = 0;
-      
+	
+	AtomCount *nextAtomCount = 0;
+	
+	if (iter + 1 < m_atomCountList.size())
+	  {
+	    nextAtomCount = m_atomCountList.at(iter + 1);
+	    
+	    if (nextAtomCount->count() > 0)
+	      nextNegative = false;
+	    else
+	      nextNegative = true;
+	  }
+	else
+	  {
+	    // We are already at the last item,
+	    // so we do not add a space at the end of a negative
+	    // item:
+	
+	    nextNegative = true;
+	  }
+	
 	atomCount = m_atomCountList.at(iter);
 
-	composition += QString("%1%2")
-	  .arg(atomCount->symbol())
-	  .arg(atomCount->count());
+	// Do not list item if it is 0-count.
+	if (!atomCount->count())
+	  continue;
+	
+	if (atomCount->count() > 0)
+	  {
+	    // The count is positive, just list the item as "C12"
+
+	  composition += QString("%1%2")
+	    .arg(atomCount->symbol())
+	    .arg(atomCount->count());
+
+	  nextNegative = false;
+	  }
+	else
+	  {
+	    // The count is negative, so we have to list the item as
+	    // "-C12", but then, we do not want to have "-C-12"
+	    // because count will be negative, thus we change its
+	    // value to positive by *ying by -1. 
+
+	    // Note how we put a %3 arg after the item, so that if
+	    // next items are positive they do not get factorized
+	    // erroneously under the negative sign. This only in case
+	    // the next item is positive. If the previous item was
+	    // negative, we do not need any supplementary space
+	    // because we are adding a '-' anyways.
+
+	    composition += QString("-%1%2%3")
+	      .arg(atomCount->symbol())
+	      .arg(atomCount->count() * -1)
+	      .arg(nextNegative ? "" : "+");
+
+	    nextNegative = true;
+	  }
       }
-  
+        
     return composition;
   }
 
@@ -1336,6 +1487,11 @@ namespace massXpert
   
     m_formula = element.text();
   
+    // Do not forget that we might have a title associated with the
+    // formula and spaces. checkSyntax() should care of removing these
+    // title and spaces before checking for chemical syntax
+    // correctness.
+
     return checkSyntax();
   }
 
