@@ -224,18 +224,18 @@ namespace massXpert
 	      return -1;
 	    }
       
-	// At this moment, the new fragment might be challenged for the
-	// fragmented monomer's side chain contribution. For example, in
+	// At this moment, the new fragment might be challenged for
+	// the fragmented monomer's contribution. For example, in
 	// nucleic acids, it happens that during a fragmentation, the
 	// base of the fragmented monomer is decomposed and goes
 	// away. This is implemented in massXpert with the ability to
 	// tell the fragmenter that upon fragmentation the mass of the
-	// monomer is to be removed. The skeleton mass is then added to
-	// the formula of the fragmentation pattern.
+	// monomer is to be removed. The skeleton mass is then added
+	// to the formula of the fragmentation pattern.
 
-	int sideChainContrib = fragOptions.sideChainContribution();
+	int monomerContrib = fragOptions.monomerContribution();
 
-	if(sideChainContrib)
+	if(monomerContrib)
 	  {
 	    const Monomer *monomer = mp_polymer->at(iter);
 	  
@@ -243,7 +243,7 @@ namespace massXpert
 	  		
 	    if (!monomer->accountMasses(&oligomer1->rmono(),
 					 &oligomer1->ravg(),
-					 sideChainContrib))
+					 monomerContrib))
 	      {
 		delete oligomer1;
 	      
@@ -546,9 +546,9 @@ namespace massXpert
 	// monomer is to be removed. The skeleton mass is then added to
 	// the formula of the fragmentation pattern.
 
-	int sideChainContrib = fragOptions.sideChainContribution();
+	int monomerContrib = fragOptions.monomerContribution();
       
-	if(sideChainContrib)
+	if(monomerContrib)
 	  {
 	    const Monomer *monomer = mp_polymer->at(iter);
 	  
@@ -556,7 +556,7 @@ namespace massXpert
 	  		
 	    if (!monomer->accountMasses(&oligomer1->rmono(),
 					 &oligomer1->ravg(),
-					 sideChainContrib))
+					 monomerContrib))
 	      {
 		delete oligomer1;
 	      
@@ -952,9 +952,9 @@ namespace massXpert
 	// monomer is to be removed. The skeleton mass is then added to
 	// the formula of the fragmentation pattern.
 
-	int sideChainContrib = fragOptions.sideChainContribution();
+	int monomerContrib = fragOptions.monomerContribution();
       
-	if(sideChainContrib)
+	if(monomerContrib)
 	  {
 	    const Monomer *monomer = mp_polymer->at(iter);
 	  
@@ -962,7 +962,7 @@ namespace massXpert
 	  		
 	    if (!monomer->accountMasses(&oligomer1->rmono(),
 					 &oligomer1->ravg(),
-					 sideChainContrib))
+					 monomerContrib))
 	      {
 		delete oligomer1;
 	      
@@ -1134,6 +1134,10 @@ namespace massXpert
 	    int startIonizeLevel = fragOptions.startIonizeLevel();
 	    int endIonizeLevel = fragOptions.endIonizeLevel();
 
+// 		qDebug() << __FILE__ << __LINE__ 
+// 			 << "ionizeRule formula:" 
+// 			 << ionizeRule.formula();
+
 	    for (int kter = startIonizeLevel; kter < endIonizeLevel; ++kter)
 	      {
 		IonizeRule ionizeRule(m_ionizeRule);
