@@ -700,9 +700,8 @@ namespace massXpert
   
     if (!chemEntVignetteRenderer->isValid())
       {
-	if(chemEntVignetteRenderer)
-	  delete chemEntVignetteRenderer;
-      
+	delete chemEntVignetteRenderer;
+	
 	return 0;
       }
   
@@ -769,8 +768,7 @@ namespace massXpert
   
     if (!chemEntVignetteRenderer->isValid())
       {
-	if(chemEntVignetteRenderer)
-	  delete chemEntVignetteRenderer;
+	delete chemEntVignetteRenderer;
       
 	return 0;
       }
