@@ -421,6 +421,14 @@ namespace massXpert
       {
 	if(iter >= codeLength)
 	  {
+	    // Because we have progressed farther than authorized by
+	    // the number of characters allowed in the monomer codes
+	    // of this polymer chemistry definition, we decrement iter
+	    // and break the loop... Later in this function, we'll set
+	    // the proper index in the sequence where next parsing run
+	    // should occurs (the calling function will increment
+	    // *index by one).
+
 	    --iter;
 	    break;
 	  }
@@ -432,14 +440,23 @@ namespace massXpert
       
 	if(!curChar.isLetter())
 	  {
-	    // 	  qDebug() << __FILE__ << __LINE__
-	    //                  << "The character is not a letter:"
-	    // 		    << curChar;
-	  
-	    --iter;
+// 	    qDebug() << __FILE__ << __LINE__
+// 		     << "The character is not a letter:"
+// 		     << curChar;
 	  
 	    *err = curChar;
-	  
+
+	    // The non-Letter character might be '/', which would be
+	    // perfectly fine, as we use it to symbolize the actual
+	    // cleavage site. Which means that we will continue
+	    // parsing the rest of the string : we have to give the
+	    // current position back to the caller in the *index
+	    // variable for the next call to this function to start at
+	    // next character (not falling back to '/', which would
+	    // make us enter in an infinite loop).
+
+	    *index = *index + iter;
+
 	    return -1;
 	  }
       
@@ -449,9 +466,10 @@ namespace massXpert
 	  {
 	    if (isLower)
 	      {
-// 		qDebug() << "First character of monomer code might not be"
-// 			  << "lower case; sequence is"
-// 			  << m_monomerText.toAscii();
+		qDebug() << __FILE__ << __LINE__ 
+			 << "First character of monomer code might not be"
+			 << "lower case; sequence is"
+			 << m_monomerText.toAscii();
 		
 		*err = curChar;
 	      
@@ -676,9 +694,14 @@ namespace massXpert
 //     qDebug() << __FILE__ << __LINE__ << "In call at() with value:"
 // 	      << index ;
 
-    Q_ASSERT(index >= 0);
-    Q_ASSERT(index < m_monomerList.size());
-  
+    if (index < 0)
+      qFatal("%s@%d -- Index cannot be less than 0.",
+	     __FILE__, __LINE__);
+
+    if (index > m_monomerList.size())
+      qFatal("%s@%d -- Index cannot be greater than polymer size.",
+	     __FILE__, __LINE__);
+
     return m_monomerList.at(index);
   }
 
